@@ -24,6 +24,7 @@
 #'    \item{warning_train:}{Probability to signal a warning during train.}
 #'    \item{x:}{Numeric tuning parameter. Has no effect.}
 #'    \item{iter:}{Integer parameter for testing hotstarting.}
+#'    \item{count_marshaling:}{If `TRUE`, `marshal_model` will increase the `marshal_count` by 1 each time it is called. The default is `FALSE`.}
 #' }
 #' Note that segfaults may not be triggered reliably on your operating system.
 #' Also note that if they work as intended, they will tear down your R session immediately!
@@ -49,39 +50,62 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
+      param_set = ps(
+        error_predict        = p_dbl(0, 1, default = 0, tags = "predict"),
+        error_train          = p_dbl(0, 1, default = 0, tags = "train"),
+        message_predict      = p_dbl(0, 1, default = 0, tags = "predict"),
+        message_train        = p_dbl(0, 1, default = 0, tags = "train"),
+        predict_missing      = p_dbl(0, 1, default = 0, tags = "predict"),
+        predict_missing_type = p_fct(c("na", "omit"), default = "na", tags = "predict"),
+        save_tasks           = p_lgl(default = FALSE, tags = c("train", "predict")),
+        segfault_predict     = p_dbl(0, 1, default = 0, tags = "predict"),
+        segfault_train       = p_dbl(0, 1, default = 0, tags = "train"),
+        sleep_train          = p_uty(tags = "train"),
+        sleep_predict        = p_uty(tags = "predict"),
+        threads              = p_int(1L, tags = c("train", "threads")),
+        warning_predict      = p_dbl(0, 1, default = 0, tags = "predict"),
+        warning_train        = p_dbl(0, 1, default = 0, tags = "train"),
+        x                    = p_dbl(0, 1, tags = "train"),
+        iter                 = p_int(1, default = 1, tags = c("train", "hotstart")),
+        count_marshaling     = p_lgl(default = FALSE, tags = "train")
+      )
       super$initialize(
         id = "classif.debug",
+        param_set = param_set,
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         predict_types = c("response", "prob"),
-        param_set = ps(
-          error_predict        = p_dbl(0, 1, default = 0, tags = "predict"),
-          error_train          = p_dbl(0, 1, default = 0, tags = "train"),
-          message_predict      = p_dbl(0, 1, default = 0, tags = "predict"),
-          message_train        = p_dbl(0, 1, default = 0, tags = "train"),
-          predict_missing      = p_dbl(0, 1, default = 0, tags = "predict"),
-          predict_missing_type = p_fct(c("na", "omit"), default = "na", tags = "predict"),
-          save_tasks           = p_lgl(default = FALSE, tags = c("train", "predict")),
-          segfault_predict     = p_dbl(0, 1, default = 0, tags = "predict"),
-          segfault_train       = p_dbl(0, 1, default = 0, tags = "train"),
-          sleep_train          = p_uty(tags = "train"),
-          sleep_predict        = p_uty(tags = "predict"),
-          threads              = p_int(1L, tags = c("train", "threads")),
-          warning_predict      = p_dbl(0, 1, default = 0, tags = "predict"),
-          warning_train        = p_dbl(0, 1, default = 0, tags = "train"),
-          x                    = p_dbl(0, 1, tags = "train"),
-          iter                 = p_int(1, default = 1, tags = c("train", "hotstart"))
-        ),
-        properties = c("twoclass", "multiclass", "missings", "hotstart_forward"),
+        properties = c("twoclass", "multiclass", "missings", "hotstart_forward", "marshal"),
         man = "mlr3::mlr_learners_classif.debug",
         data_formats = c("data.table", "Matrix"),
         label = "Debug Learner for Classification"
       )
+    },
+    #' @description
+    #' Marshal the learner's model.
+    #' @param ... (any)\cr
+    #'   Additional arguments passed to [`marshal_model()`].
+    marshal = function(...) {
+      learner_marshal(.learner = self, ...)
+    },
+    #' @description
+    #' Unmarshal the learner's model.
+    #' @param ... (any)\cr
+    #'   Additional arguments passed to [`unmarshal_model()`].
+    unmarshal = function(...) {
+      learner_unmarshal(.learner = self, ...)
+    }
+  ),
+  active = list(
+    #' @field marshaled (logical(1))\cr
+    #' Whether the learner has been marshaled.
+    marshaled = function() {
+      learner_marshaled(self)
     }
   ),
-
   private = list(
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
+      pv$count_marshaling = pv$count_marshaling %??% FALSE
       roll = function(name) {
         name %in% names(pv) && pv[[name]] > runif(1L)
       }
@@ -105,11 +129,15 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
       }
 
       model = list(response = as.character(sample(task$truth(), 1L)), pid = Sys.getpid(), iter = pv$iter,
-        id = UUIDgenerate())
+        id = UUIDgenerate(), random_number = sample(100000, 1))
       if (isTRUE(pv$save_tasks)) {
         model$task_train = task$clone(deep = TRUE)
       }
 
+      if (isTRUE(pv$count_marshaling)) {
+        model$marshal_count = 0L
+      }
+
       set_class(model, "classif.debug_model")
     },
 
@@ -193,3 +221,21 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
 
 #' @include mlr_learners.R
 mlr_learners$add("classif.debug", function() LearnerClassifDebug$new())
+
+#' @export
+#' @method marshal_model classif.debug_model
+marshal_model.classif.debug_model = function(model, inplace = FALSE, ...) {
+  if (!is.null(model$marshal_count)) {
+    model$marshal_count = model$marshal_count + 1
+  }
+  structure(list(
+    marshaled = model, packages = "mlr3"),
+    class = c("classif.debug_model_marshaled", "marshaled")
+  )
+}
+
+#' @export
+#' @method unmarshal_model classif.debug_model_marshaled
+unmarshal_model.classif.debug_model_marshaled = function(model, inplace = FALSE, ...) {
+  model$marshaled
+}
