@@ -27,7 +27,7 @@ test_that("updating model works / resample", {
   learner = lrn("classif.debug", save_tasks = TRUE)
   rr = resample(tsk("iris"), learner, rsmp("holdout"), store_models = TRUE)
   new_learner = rr$learners[[1]]
-  expect_list(new_learner$model, len = 6)
+  expect_list(new_learner$model, len = 7)
 })
 
 test_that("NA predictions", {
@@ -71,3 +71,13 @@ test_that("default_values works with empty search space", {
   learner = lrn("classif.debug")
   expect_list(default_values(learner, ps(), task), len = 0)
 })
+
+test_that("marshaling", {
+  l = lrn("classif.debug")
+  expect_learner(l, tsk("iris"))
+  task = tsk("iris")
+  l$train(task)
+  p1 = l$predict(task)
+  p2 = l$marshal()$unmarshal()$predict(task)
+  expect_equal(p1, p2)
+})
